pub(crate) enum MetaCommands {
Show 17 variants
Pause,
Resume,
ResumeBackfill {
job_id: Option<JobId>,
fragment_id: Option<FragmentId>,
},
ClusterInfo,
SourceSplitInfo {
ignore_id: bool,
},
Reschedule {
plan: Option<String>,
revision: Option<u64>,
from: Option<String>,
dry_run: bool,
resolve_no_shuffle: bool,
},
BackupMeta {
remarks: Option<String>,
},
RestoreMeta {
opts: RestoreOpts,
},
DeleteMetaSnapshots {
snapshot_ids: Vec<u64>,
},
ListConnections,
ListServingFragmentMapping,
UnregisterWorkers {
workers: Vec<String>,
yes: bool,
ignore_not_found: bool,
check_fragment_occupied: bool,
},
ValidateSource {
props: String,
},
SetCdcTableBackfillParallelism {
table_id: u32,
parallelism: u32,
},
AlterSourcePropertiesSafe {
source_id: u32,
props: String,
reset_splits: bool,
},
ResetSourceSplits {
source_id: u32,
},
InjectSourceOffsets {
source_id: u32,
offsets: String,
},
}Variants
Pause
pause the stream graph
Resume
resume the stream graph
ResumeBackfill
force resume backfill for troubleshooting
ClusterInfo
get cluster info
SourceSplitInfo
get source split info
Reschedule
Reschedule the actors in the stream graph
The format is fragment_id-[worker_id:count]+[worker_id:count]
You can provide either decreased worker_ids only or increased only, but decreased should be preceded by
added when both are provided.
For example, for plan 100-[1:1]+[4:1] the follow request will be generated:
{
100: WorkerReschedule {
increased_actor_count: { 1: 1 },
decreased_actor_count: { 4: 1 },
}
}Use ; to separate multiple fragment
Fields
BackupMeta
backup meta by taking a meta snapshot
RestoreMeta
restore meta by recovering from a meta snapshot
Fields
opts: RestoreOptsDeleteMetaSnapshots
delete meta snapshots
ListConnections
List all existing connections in the catalog
ListServingFragmentMapping
List fragment mapping for serving
UnregisterWorkers
Unregister workers from the cluster
Fields
ValidateSource
Validate source interface for the cloud team
Fields
SetCdcTableBackfillParallelism
AlterSourcePropertiesSafe
Alter source connector properties with pause/resume orchestration (UNSAFE) This operation pauses the source, updates properties, and resumes.
Fields
ResetSourceSplits
Reset source split assignments (UNSAFE - admin only) Clears cached split state and triggers re-discovery from upstream.
InjectSourceOffsets
Inject specific offsets into source splits (UNSAFE - admin only) WARNING: This can cause data duplication or loss!